@@ -14,13 +14,20 @@ Server users: data bag search, and node search.
 .. _Chef: http://wiki.opscode.com/display/chef/Home
 
 """
-__version__ = "1.2.2"
+__version__ = "1.3.0"
 __author__ = "Miquel Torres <tobami@gmail.com>"
 
 __cooking__ = False
 
 chef_environment = None
+
 loglevel = "info"
 verbose = False
-LOGFILE = '/var/log/chef/solo.log'
 enable_logs = True
+LOGFILE = '/var/log/chef/solo.log'
+whyrun = False
+
+node_work_path = '/tmp/chef-solo'
+cookbook_paths = ['site-cookbooks', 'cookbooks']
+
+CONFIGFILE = 'config.cfg'
