@@ -1,4 +1,4 @@
-#Copyright 2010-2012 Miquel Torres <tobami@googlemail.com>
+#Copyright 2010-2012 Miquel Torres <tobami@gmail.com>
 #
 #Licensed under the Apache License, Version 2.0 (the "License");
 #you may not use this file except in compliance with the License.
@@ -25,9 +25,9 @@ from fabric import colors
 from fabric.utils import abort
 from fabric.contrib.project import rsync_project
 
+from littlechef import cookbook_paths, whyrun
 from littlechef import lib
 from littlechef import solo
-from littlechef.settings import cookbook_paths
 from littlechef import LOGFILE, enable_logs as ENABLE_LOGS
 
 
@@ -76,9 +76,9 @@ def sync_node(node):
     It also injects the ipaddress to the node's config file if not already
     existent.
     """
-    if node.get('dummy'):
+    if node.get('dummy') or 'dummy' in node.get('tags', []):
         lib.print_header("Skipping dummy: {0}".format(env.host))
-        return
+        return False
     # Get merged attributes
     current_node = _build_node_data_bag()
     with lib.credentials():
@@ -98,6 +98,7 @@ def sync_node(node):
         finally:
             _remove_local_node_data_bag()
             _node_cleanup()
+    return True
 
 
 def _synchronize_node(configfile, node):
@@ -335,7 +336,10 @@ def _configure_node():
     with settings(hide('stdout', 'warnings', 'running'), warn_only=True):
         sudo("mv {0} {0}.1".format(LOGFILE))
     # Build chef-solo command
-    cmd = 'chef-solo -l {0} -j /etc/chef/node.json'.format(env.loglevel)
+    cmd = "chef-solo "
+    if whyrun:
+        cmd += "--why-run "
+    cmd += '-l {0} -j /etc/chef/node.json'.format(env.loglevel)
     if ENABLE_LOGS:
         cmd += ' | tee {0}'.format(LOGFILE)
     if env.loglevel == "debug":
