@@ -22,7 +22,7 @@ from fabric import colors
 from fabric.api import env, settings
 from fabric.utils import abort
 
-from littlechef.settings import cookbook_paths
+from littlechef import cookbook_paths
 
 
 knife_installed = True
@@ -265,7 +265,7 @@ def get_recipes_in_role(rolename):
 def get_recipes_in_node(node):
     """Gets the name of all recipes present in the run_list of a node"""
     recipes = []
-    for elem in node.get('run_list'):
+    for elem in node.get('run_list', []):
         if elem.startswith("recipe"):
             recipe = elem.split('[')[1].split(']')[0]
             recipes.append(recipe)
@@ -306,7 +306,7 @@ def get_roles_in_node(node, recursive=False, depth=0):
     """
     LIMIT = 5
     roles = []
-    for elem in node.get('run_list'):
+    for elem in node.get('run_list', []):
         if elem.startswith("role"):
             role = elem.split('[')[1].split(']')[0]
             if role not in roles:
@@ -454,6 +454,10 @@ def credentials(*args, **kwargs):
         # translate from ssh params to fabric params
         if 'identityfile' in credentials:
             credentials['key_filename'] = credentials['identityfile']
+        # SSH LogLevel != overall env loglevel, so don't override the env's
+        # loglevel with SSH's
+        if 'loglevel' in credentials:
+            del credentials['loglevel']
         credentials.update(kwargs)
     else:
         credentials = kwargs
