@@ -1,4 +1,4 @@
-#Copyright 2010-2012 Miquel Torres <tobami@googlemail.com>
+#Copyright 2010-2012 Miquel Torres <tobami@gmail.com>
 #
 #Licensed under the Apache License, Version 2.0 (the "License");
 #you may not use this file except in compliance with the License.
@@ -23,10 +23,10 @@ from fabric.contrib.files import append, exists
 from fabric.contrib.console import confirm
 from ssh.config import SSHConfig as _SSHConfig
 
+import littlechef
 from littlechef import solo
 from littlechef import lib
 from littlechef import chef
-from littlechef.settings import CONFIGFILE, cookbook_paths, node_work_path
 
 
 # Fabric settings
@@ -53,7 +53,7 @@ def new_kitchen():
     _mkdir("nodes")
     _mkdir("roles")
     _mkdir("data_bags")
-    for cookbook_path in cookbook_paths:
+    for cookbook_path in littlechef.cookbook_paths:
         _mkdir(cookbook_path)
     # Add skeleton config.cfg
     if not os.path.exists("config.cfg"):
@@ -316,7 +316,7 @@ def _readconfig():
     """Configures environment variables"""
     config = ConfigParser.SafeConfigParser()
     try:
-        found = config.read([CONFIGFILE, 'auth.cfg'])
+        found = config.read([littlechef.CONFIGFILE, 'auth.cfg'])
     except ConfigParser.ParsingError as e:
         abort(str(e))
     if not len(found):
@@ -384,18 +384,17 @@ def _readconfig():
         env.node_work_path = os.path.expanduser(config.get('kitchen',
                                                 'node_work_path'))
     except (ConfigParser.NoSectionError, ConfigParser.NoOptionError):
-        env.node_work_path = node_work_path
+        env.node_work_path = littlechef.node_work_path
     else:
         if not env.node_work_path:
             abort('The "node_work_path" option cannot be empty')
 
 
 # Only read config if fix is being used and we are not creating a new kitchen
-import littlechef
 env.chef_environment = littlechef.chef_environment
 env.loglevel = littlechef.loglevel
 env.verbose = littlechef.verbose
-
+env.node_work_path = littlechef.node_work_path
 
 if littlechef.__cooking__:
     # Called from command line
