@@ -1,4 +1,4 @@
-#Copyright 2010-2012 Miquel Torres <tobami@googlemail.com>
+#Copyright 2010-2012 Miquel Torres <tobami@gmail.com>
 #
 #Licensed under the Apache License, Version 2.0 (the "License");
 #you may not use this file except in compliance with the License.
@@ -21,8 +21,8 @@ from fabric import colors
 from fabric.contrib.files import append, exists, upload_template
 from fabric.utils import abort
 
+from littlechef import cookbook_paths
 from littlechef.lib import credentials
-from littlechef.settings import cookbook_paths
 from littlechef import LOGFILE as logging_path
 
 
